<?php
/**
 * Handler for [efaq_guten_block] shortcode
 *
 * @param $atts
 *
 * @return string
 */
function efaq_block_handler($atts)
{
	$atts = shortcode_atts([
		'heading' => __('Everest FAQ Manager Lite Title'),
		'heading_tag' => 'h2',
		'efaq_id' => '',
	], $atts, 'efaq_guten_block');

	return efaq_block_renderer($atts[ 'heading' ],$atts[ 'heading_tag' ],$atts[ 'efaq_id' ]);
}

add_shortcode('efaq_guten_block', 'efaq_block_handler');

/**
 * Handler for post title block
 * @param $atts
 *
 * @return string
 */
function efaq_block_render_handler($atts)
{
	return efaq_block_renderer($atts[ 'heading' ],$atts[ 'heading_tag' ],$atts[ 'efaq_id' ]);
}

/**
 * Output the post title wrapped in a heading
 *
 * @param int $efaq_id The post ID
 * @param string $heading Allows : h2,h3,h4 only
 *
 * @return string
 */
function efaq_block_renderer($heading,$heading_tag,$efaq_id)
{
	$ret = '';
	if(!empty($heading)){
		$ret .= "<$heading_tag>$heading</$heading_tag>";
	}

	if($efaq_id!=null){
		$sht = "[everest_faq id='$efaq_id']";
		$title = do_shortcode($sht);
		$ret .= "$title";
	}
	return $ret;
}

/**
 * Register block
 */
add_action('init', function() {
	//Skip block registration if gutenberg is not enabled/merged.
	if (!function_exists('register_block_type')){
		return;
	}
	$dir = dirname(__FILE__);

	wp_enqueue_style('font-awesome-icons-v4.7.0', EFAQM_CSS_DIR . '/font-awesome/font-awesome.min.css', false, EFAQM_PLUGIN_VERSION);
    wp_enqueue_style('google-fonts', '//fonts.googleapis.com/css?family=Raleway|ABeeZee|Aguafina+Script|Open+Sans|Roboto|Roboto+Slab|Lato|Titillium+Web|Source+Sans+Pro|Playfair+Display|Montserrat|Khand|Oswald|Ek+Mukta|Rubik|PT+Sans+Narrow|Poppins|Oxygen:300,400,600,700', array(), EFAQM_PLUGIN_VERSION);
    wp_enqueue_style('efaq_frontend_css', EFAQM_CSS_DIR . '/ecfaq-frontend.css', array(), EFAQM_PLUGIN_VERSION);
    wp_enqueue_style('efaq_frontend_css', EFAQM_CSS_DIR . 'ecfaq-frontend.css', array(), EFAQM_PLUGIN_VERSION);

            //for counterup js


    wp_enqueue_script('efaq_frontend_js', EFAQM_JS_DIR . '/efaq-frontend.js', array('jquery'), EFAQM_PLUGIN_VERSION, true);
    wp_enqueue_script('efaq_frontend_js', EFAQM_JS_DIR . 'efaq-frontend.js', array('jquery'), EFAQM_PLUGIN_VERSION, true);

    $index_js = 'efaq-block.js';
    wp_register_script(
    	'efaq-block-script',
    	plugins_url($index_js, __FILE__),
    	array(
    		'wp-blocks',
    		'wp-i18n',
    		'wp-element',
    		'wp-components',
    		'wp-editor'
    	),
    	filemtime("$dir/$index_js")
    );

    $efaq_logos_array = get_efaq_logos();
    wp_localize_script( 'efaq-block-script', 'EFAQ_logos_array', $efaq_logos_array);

    register_block_type('efaq-display-block/efaq-widget', array(
    	'editor_script' => 'efaq-block-script',
    	'render_callback' => 'efaq_block_render_handler',
    	'attributes' => [
    		'heading' => [
    			'type' => 'string',
    			'default' => __('Everest FAQ Manager Lite Title')
    		],
    		'heading_tag' => [
    			'type' => 'string',
    			'default' => 'h2'
    		],
    		'efaq_id' => [
    			'type' => 'string',
    			'default' => ''
    		],
    	]
    ));
});

function get_efaq_logos(){
	$args = array('post_type'=>'everest-faq',
		'post_status'=>'publish',
		'post_per_page'=>'25'
	);
	//The Query
	$the_query = new WP_Query( $args );

	$everest_faq = array(array('value'=>'0','label'=>__('Select FAQ')));

	//The Loop
	if ( $the_query->have_posts() ) {
		while($the_query->have_posts()){
			$the_query->the_post();
			global $post;
			$everest_faq[] = array('value'=>get_the_ID(), 'label'=> get_the_title());
		}
	}

	return $everest_faq;
}